=== modified file 'ChangeLog'
--- ChangeLog	2012-02-28 10:22:26 +0000
+++ ChangeLog	2012-03-16 10:09:53 +0000
@@ -1,5 +1,22 @@
-maas-enlist (0.1) UNRELEASED; urgency=low
+maas-enlist (0.2) released; urgency=low
+
+  [ Jamie Strandboge ]
+  * bin/maas-enlist: add https:// support; defensively quote all variables;
+    fix argument processing
+  * man/maas-enlist.1: Update accordingly.
+
+  [ Andres Rodriguez ]
+  * bin/maas-enlist: Add copyright header; Remove server-port option;
+    Update maas API path to production one (http://<server>/MAAS/api...)
+  * debian/control: Depends on curl-udeb.
+  * debian/maas-enlist-udeb.{postinst,templates}: Drop server-port option.
+  * debian/po/templates.pot: Update accordingly.
+  * man/maas-enlist.1: Update accordingly.
+
+ -- Andres Rodriguez <andreserl@ubuntu.com>  Fri, 16 Mar 2012 10:09:53 -0400
+
+maas-enlist (0.1-0ubuntu1) precise; urgency=low
 
   * Initial Release (LP: #941946)
 
- -- Andres Rodriguez <andreserl@ubuntu.com>  Tue, 28 Feb 2012 10:22:26 -0500
+ -- Andres Rodriguez <andreserl@ubuntu.com>  Tue, 28 Feb 2012 10:24:16 -0500

=== modified file 'bin/maas-enlist'
--- bin/maas-enlist	2012-02-28 10:22:26 +0000
+++ bin/maas-enlist	2012-03-16 10:09:53 +0000
@@ -1,49 +1,66 @@
 #!/bin/sh
+#
+#    maas-enlist: MAAS Enlistment Tool
+#
+#    Copyright (C) 2012 Canonical Ltd.
+#
+#    Authors: Andres Rodriguez <andres.rodriguez@canonical.com>
+#
+#    This program is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation, version 3 of the License.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 get_mac_addresses() {
 	macs=`ip addr | egrep 'link/ether' | cut -d' ' -f6`
 	for i in $macs;
 	do
 		if [ -z "$mac_address" ]; then
-			mac_address=$i;
+			mac_address="$i";
 		else
-			mac_address=$mac_address,$i
+			mac_address="$mac_address,$i"
 		fi
 	done
-	echo $mac_address
+	echo "$mac_address"
 }
 
 get_mac_address_by_interface() {
-	iface=$1
-	mac=`ip addr sh $iface | egrep -m1 'link/ether' | cut -d' ' -f6`
-	echo $mac
+	iface="$1"
+	mac=`ip addr sh "$iface" | egrep -m1 'link/ether' | cut -d' ' -f6`
+	echo "$mac"
 }
 
 get_mac_address_data() {
-	input_string=$1
+	input_string="$1"
 	OIFS=$IFS; IFS=","; set -- $input_string; IFS=$OIFS
 	for i in "$@";
 	do
-		mac_address=$mac_address"&mac_addresses=""${i}";
+		mac_address="$mac_address""&mac_addresses=""${i}";
 	done
-	echo $mac_address
+	echo "$mac_address"
 }
 
 get_host_architecture() {
 	arch=`archdetect | cut -d'/' -f1`
-	echo $arch
+	echo "$arch"
 }
 
 enlist_node() {
-	serverurl=${1}
-	port=${2}
-	mac=${3}
-	arch=${4}
-	hostname=${5}
+	serverurl="${1}"
+	mac="${2}"
+	arch="${3}"
+	hostname="${4}"
 
 	curl \
 	    --data "op=new${mac}&hostname=${hostname}&architecture=${arch}&after_commissioning_action=2" \
-	    http://${serverurl}:${port}/api/1.0/nodes/
+	    "${serverurl}"/MAAS/api/1.0/nodes/
 }
 
 Error () {
@@ -55,25 +72,24 @@
 	cat <<EOF
 Usage: ${0##*/} [ options ]
 
-   node enlistment into the MaaS server
+   node enlistment into the MAAS server
 
    options:
-      -s | --serverurl        resolvable MaaS server API URL (maas.local if not specified)
-      -o | --serverport       server port number (8000 if not specified)
+      -s | --serverurl        resolvable MAAS server API URL (maas.local if not specified)
       -n | --hostname         hostname of the node to register
       -i | --interface        interface address to register (obtains MAC address)
       -a | --arch             architecture of the node to register
 
    Example:
-    - ${0##*/} --serverurl 127.0.0.1 --serverport 8000 --interface eth0
+    - ${0##*/} --serverurl 127.0.0.1 --interface eth0
 
 EOF
 }
 
 bad_Usage() { Usage 1>&2; [ $# -eq 0 ] || error "$@"; exit 1; }
 
-short_opts="hs:o:n:i:a:"
-long_opts="help,serverurl:,serverport:,hostname:,interface:,arch:"
+short_opts="hs:n:i:a:"
+long_opts="help,serverurl:,hostname:,interface:,arch:"
 getopt_out=$(getopt --name "${0##*/}" \
 	--options "${short_opts}" --long "${long_opts}" -- "$@") &&
 	eval set -- "${getopt_out}" ||
@@ -84,10 +100,9 @@
 	case "$cur" in
 		-h|--help) Usage ; exit 0;;
 		-s|--serverurl) serverurl=${2}; shift;;
-		-o|--serverport) port=${2}; shift;;
 		-n|--hostname) hostname=${2}; shift;;
 		-i|--interface) iface=${2}; shift;;
-		-a|--arch) iface=${2}; shift;;
+		-a|--arch) arch=${2}; shift;;
 		--) shift; break;;
 	esac
 	shift;
@@ -100,18 +115,27 @@
 if [ -z "$iface" ]; then
 	mac_addrs=$(get_mac_addresses)
 else
-	mac_addrs=$(get_mac_address_by_interface $iface)
-fi
-
-# If no port is specified, assume the default.
-if [ -z "$port" ]; then
-	port=8000
+	mac_addrs=$(get_mac_address_by_interface "$iface")
+fi
+
+protocol=
+servername=
+if echo "$serverurl" | egrep -q '^[a-z]+://' ; then
+	protocol=`echo "$serverurl" | sed 's#^\([a-z]\+\)://.*#\\1#'`
+	servername=`echo "$serverurl" | sed 's#^[a-z]\+://##'`
+else
+	protocol="http"
+	servername="$serverurl"
+fi
+
+if [ "$protocol" != "http" ] && [ "$protocol" != "https" ]; then
+	Error "Invalid protocol '$protocol'"
 fi
 
 #TODO: Verify that it's a valid hostname (sanitize it)
-if [ -z "$serverurl" ]; then
+if [ -z "$servername" ]; then
 	serverurl="maas.local"
-elif echo $serverurl | grep -qs '^[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}$'; then
+elif echo "$servername" | grep -qs '^[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}$'; then
 	continue
 # TODO: Check hostname URL is valid
 #else
@@ -129,6 +153,6 @@
 fi
 
 # Obtain the MAC addresses data
-mac=$(get_mac_address_data $mac_addrs)
+mac=$(get_mac_address_data "$mac_addrs")
 
-enlist_node $serverurl $port $mac $arch $hostname
+enlist_node "$protocol://$servername" "$mac" "$arch" "$hostname"

=== modified file 'man/maas-enlist.1'
--- man/maas-enlist.1	2012-02-28 10:22:26 +0000
+++ man/maas-enlist.1	2012-03-16 10:09:53 +0000
@@ -2,7 +2,7 @@
 .SH NAME
 maas-enlist -- MaaS Enlistment tool, for enlisting with a MaaS server over a network
 .SH SYNOPSIS
-.B maas-enlist --serverurl=127.0.0.1 --serverport 8000 --hostname=test-node --mac-address=AA:BB:CC:DD:EE:FF,AA:BB:CC:DD:EE:F1
+.B maas-enlist --serverurl=[protocol://]127.0.0.1 --hostname=test-node --mac-address=AA:BB:CC:DD:EE:FF,AA:BB:CC:DD:EE:F1
 
 .SH DESCRIPTION
 .IP
@@ -11,10 +11,9 @@
 Parameters: 
 .TP
 \fB\-s\fR, \fB\-\-serverurl\fR
-\fB\-\-\fR resolvable IP or hostname of the MaaS server
-.TP
-\fB\-o\fR, \fB\-\-serverport\fR
-\fB\-\-\fR port number of the MaaS server to be used
+\fB\-\-\fR resolvable IP or hostname of the MaaS server. May optionally prefix
+http:// or https:// to explicitly set the protocol. If unspecified, the protocol
+is http://.
 .TP
 \fB\-n\fR, \fB\-\-hostname\fR
 \fB\-\-\fR hostname to assign the node
@@ -29,5 +28,5 @@
 .IP
 all other parameters are required
 .SH "WARNING"
-Currently all traffic sent is done so via plain HTTP.  SSL is currently not supported.
-It is strongly recommended that this tool is only used in a trusted network segment.
+When using http:// as the protocol, all traffic sent unencrypted. It is
+strongly recommended that http:// only be used in a trusted network segment.

